@@ -562,7 +562,7 @@ class RefundStatusEnum(str, Enum):
     PROCESSING = "processing"
 
 
-class RefundInitateResponse(BaseModel):
+class RefundInitiateResponse(BaseModel):
     """Refund initiation response."""
 
     APIConnect: APIConnectEnum
@@ -573,7 +573,7 @@ class RefundInitateResponse(BaseModel):
     errorReason: Optional[str]
 
 
-class RefundResponse(RefundInitateResponse):
+class RefundResponse(RefundInitiateResponse):
     """Refund response."""
 
     initiated_on: datetime
@@ -637,7 +637,7 @@ class APIResponse(BaseModel):
             IPNResponse,
             PaymentInitResponse,
             RefundResponse,
-            RefundInitateResponse,
+            RefundInitiateResponse,
             TransactionBySessionResponse,
             TransactionsByIDResponse,
         ]
